PropertyMapper class

Constructors

PropertyMapper({PugLogger logger = const NoopPugLogger()})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
logger PugLogger
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

mapEventProperties(String kind, Map<String, Object?> properties) Map<String, PropertyValue>?
mapProperties(Map<String, Object?> properties) Map<String, PropertyValue>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited